==> jc-1.4.0.tar.gz: java/util/WeakHashMap__24WeakEntrySet.h <==
// final class java.util.WeakHashMap$WeakEntrySet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class f516b3964b72837e java_util_WeakHashMap__24WeakEntrySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_WeakHashMap__24WeakEntrySet_H_
#define _JC_java_util_WeakHashMap__24WeakEntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs	_jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$refs	_jc_java_util_WeakHashMap__24WeakEntrySet$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$object	_jc_java_util_WeakHashMap__24WeakEntrySet$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vmethods	_jc_java_util_WeakHashMap__24WeakEntrySet$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtable	_jc_java_util_WeakHashMap__24WeakEntrySet$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtype	_jc_java_util_WeakHashMap__24WeakEntrySet$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakEntrySet$method$_init$7bbfd636b1996e02(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *, struct _jc_java_util_WeakHashMap$object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_WeakHashMap__24WeakEntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *);
extern jint _jc_java_util_WeakHashMap__24WeakEntrySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *);
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vmethods	java_util_WeakHashMap__24WeakEntrySet;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs {
	struct _jc_java_util_WeakHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$refs {
    _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs	java_util_WeakHashMap__24WeakEntrySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs	java_util_WeakHashMap__24WeakEntrySet;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet$object {
	_jc_java_util_WeakHashMap__24WeakEntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakEntrySet$vtype _jc_java_util_WeakHashMap__24WeakEntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakEntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakEntrySet$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakEntrySet_H_ */

==> jc-1.4.6.tar.gz: java/util/WeakHashMap__24WeakEntrySet.h <==
// final class java.util.WeakHashMap$WeakEntrySet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class f516b3964b72837e java_util_WeakHashMap__24WeakEntrySet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_WeakHashMap__24WeakEntrySet_H_
#define _JC_java_util_WeakHashMap__24WeakEntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs	_jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$refs	_jc_java_util_WeakHashMap__24WeakEntrySet$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet$object	_jc_java_util_WeakHashMap__24WeakEntrySet$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vmethods	_jc_java_util_WeakHashMap__24WeakEntrySet$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtable	_jc_java_util_WeakHashMap__24WeakEntrySet$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtype	_jc_java_util_WeakHashMap__24WeakEntrySet$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakEntrySet$method$_init$7bbfd636b1996e02(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *, struct _jc_java_util_WeakHashMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_WeakHashMap__24WeakEntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_WeakHashMap__24WeakEntrySet$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vmethods	java_util_WeakHashMap__24WeakEntrySet;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakEntrySet$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs {
	struct _jc_java_util_WeakHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$refs {
    _jc_java_util_WeakHashMap__24WeakEntrySet$sub_refs	java_util_WeakHashMap__24WeakEntrySet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_WeakHashMap__24WeakEntrySet$sub_nonrefs	java_util_WeakHashMap__24WeakEntrySet;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet$object {
	_jc_java_util_WeakHashMap__24WeakEntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakEntrySet$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakEntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakEntrySet$vtype _jc_java_util_WeakHashMap__24WeakEntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakEntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakEntrySet$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakEntrySet_H_ */
